Year class

Year Model*

Constructors

Year({required int year, required List<Holiday> holidays})
Year.fromJson(Map<String, dynamic> json)
Convert a json string to Year
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
holidays List<Holiday>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
year int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert a Year to json string
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited